@@ -4,7 +4,7 @@ package Dist::Zilla::App::Command::stale;
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 # ABSTRACT: print your distribution's prerequisites and plugins that are out of date
 
-our $VERSION = '0.051';
+our $VERSION = '0.052';
 
 use Dist::Zilla::App -command;
 
@@ -134,7 +134,7 @@ sub execute
     };
 
     $self->app->chrome->logger->unmute;
-    $self->log(join("\n", @stale_modules));
+    $self->log(join("\n", @stale_modules)); # this might be just a blank line
     $self->log([ 'got error from stale_modules check: %s', $error ]) if $error and not @stale_modules;
 }
 
@@ -167,7 +167,7 @@ Dist::Zilla::App::Command::stale - print your distribution's prerequisites and p
 
 =head1 VERSION
 
-version 0.051
+version 0.052
 
 =head1 SYNOPSIS
 
