@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::PromptIfStale; # git description: v0.050-2-g75db88c
+package Dist::Zilla::Plugin::PromptIfStale; # git description: v0.051-7-ge435110
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 # ABSTRACT: Check at build/release time if modules are out of date
 # KEYWORDS: prerequisites upstream dependencies modules metadata update stale
 
-our $VERSION = '0.051';
+our $VERSION = '0.052';
 
 use Moose;
 with 'Dist::Zilla::Role::BeforeBuild',
@@ -191,7 +191,7 @@ sub stale_modules
         next if $already_checked{$module};
 
         # these core modules should be indexed, but aren't
-        if (any { $module eq $_ } qw(Config DB Errno NEXT Pod::Functions))
+        if (any { $module eq $_ } qw(Config DB Errno Pod::Functions))
         {
             $self->log_debug([ 'skipping core module: %s', $module ]);
             $already_checked{$module}++;
@@ -495,7 +495,7 @@ Dist::Zilla::Plugin::PromptIfStale - Check at build/release time if modules are
 
 =head1 VERSION
 
-version 0.051
+version 0.052
 
 =head1 SYNOPSIS
 
